@@ -10,9 +10,9 @@ test_that("modelsummary works with glance", {
   model2 <- lm_robust(mpg ~ am, mtcars, clusters = cyl)
   model3 <- lm_lin(mpg ~ am, ~ cyl, mtcars)
 
-  mso <- modelsummary::extract(list(model1, model2, model3))
+  mso <- modelsummary::modelsummary(list(model1, model2, model3), output = "data.frame")
 
-  expect_equal(colnames(mso), c("group", "term", "statistic", 
+  expect_equal(colnames(mso), c("group", "term", "statistic",
                                 "Model 1", "Model 2", "Model 3"))
 
   expect_equal(nrow(mso), 12L)
@@ -23,8 +23,9 @@ test_that("modelsummary works with glance", {
   model1 <- iv_robust(mpg ~ am | gear, mtcars)
   model2 <- iv_robust(mpg ~ am | gear, mtcars, clusters = cyl, diagnostics = TRUE)
 
-  mso <- modelsummary::extract(list(model1, model2), 
-                               gof_omit = c("N|[sS]tatistic|p.value|p{1}"))
+  mso <- modelsummary::modelsummary(list(model1, model2),
+                               gof_omit = c("N|[sS]tatistic|p.value|p{1}"),
+                               output = "data.frame")
 
   expect_equal(nrow(mso), 6)
 
@@ -33,14 +34,14 @@ test_that("modelsummary works with glance", {
   # difference_in_means
   model1 <- difference_in_means(mpg ~ am, mtcars)
   model2 <- difference_in_means(mpg ~ am, mtcars, blocks = vs)
-  mso <- modelsummary::extract(list(model1, model2))
+  mso <- modelsummary:::extract_models(list(model1, model2))
 
 
   # horvitz_thompson
   model1 <- horvitz_thompson(mpg ~ am, mtcars)
   model2 <- horvitz_thompson(mpg ~ am, mtcars, blocks = vs)
 
-  mso <- modelsummary::extract(list(model1, model2))
+  mso <- modelsummary::modelsummary(list(model1, model2), output = "data.frame")
 
   expect_equal(nrow(mso), 6)
 
